import { AbstractBatch, AbstractGetOptions, AbstractIterator, AbstractIteratorOptions, AbstractLevelDOWN, AbstractOptions, ErrorCallback, ErrorValueCallback } from 'abstract-leveldown';
import { StringOrBuffer } from './types';
import { EasierLevelDOWNEmitter } from 'easier-abstract-leveldown';
export declare type LevelDOWNMounts = Array<{
    mount: string;
    db: AbstractLevelDOWN;
    options?: any;
}>;
export interface LevelDOWNMountOptions {
    db: AbstractLevelDOWN;
    options?: any;
    mounts?: LevelDOWNMounts;
}
/**
 * LevelMount, like file system directory mounts and somewhat like the opposite of subleveldown.
 * Can be used *with* subleveldown. Examples:
 *
 * const hybrid_db = levelup(levelmount({
 *   db: leveldown('root'),
 *   options: {}, // options for leveldown
 *   mounts: [
 *     {
 *       mount: '!tmp!',
 *       db: memdown(),
 *     },
 *     {
 *       mount: '!var!',
 *       db: someotherdown(),
 *       options: {}, // someotherdown options for _open
 *     }
 *   ],
 * })
 *
 * hybrid_db.put('hello', 'world') // ends up in root leveldown with key `hello`
 * hybrid_db.put('!tmp!blah', 'bleh') // ends up in memdown with key `blah`
 *
 * const var_db = subleveldown(hybrid_db, 'var', { separator: '!' })
 * var_db.put('goodbye', 'world') // ends up in someotherdown with key `goodbye`
 */
export declare class LevelDOWNMount<K extends StringOrBuffer = string, V = any, O extends LevelDOWNMountOptions = any> extends AbstractLevelDOWN<K, V> {
    _mounts: LevelDOWNMounts;
    constructor(opts: O);
    _resolve_mount(key: K): {
        db: AbstractLevelDOWN<any, any>;
        mount: string;
        path: K;
    };
    _open(opts: O, callback: ErrorCallback): void;
    _close(callback: ErrorCallback): void;
    _get(key: K, options: AbstractGetOptions, callback: ErrorValueCallback<V>): void;
    _put(key: K, val: V, options: AbstractOptions, callback: ErrorCallback): void;
    _del(key: K, options: AbstractOptions, callback: ErrorCallback): void;
    _batch(array: ReadonlyArray<AbstractBatch<K, V>>, options: AbstractOptions, cb: ErrorCallback): void;
    _iterator(options: AbstractIteratorOptions<K>): AbstractIterator<K, V>;
    changes(): EasierLevelDOWNEmitter<K, V>;
}
